[llvm-commits] CVS: llvm/include/llvm/PassAnalysisSupport.h

Misha Brukman brukman at cs.uiuc.edu
Fri Mar 12 00:14:01 PST 2004


Changes in directory llvm/include/llvm:

PassAnalysisSupport.h updated: 1.17 -> 1.18

---
Log message:

Add AnalysisUsage::addRequiredTransitive() to keep analysis info alive for
future queries by clients.


---
Diffs of the changes:  (+17 -4)

Index: llvm/include/llvm/PassAnalysisSupport.h
diff -u llvm/include/llvm/PassAnalysisSupport.h:1.17 llvm/include/llvm/PassAnalysisSupport.h:1.18
--- llvm/include/llvm/PassAnalysisSupport.h:1.17	Tue Nov 11 16:41:30 2003
+++ llvm/include/llvm/PassAnalysisSupport.h	Fri Mar 12 00:13:15 2004
@@ -25,14 +25,15 @@
 
 //===----------------------------------------------------------------------===//
 // AnalysisUsage - Represent the analysis usage information of a pass.  This
 // tracks analyses that the pass REQUIRES (must available when the pass runs),
 // and analyses that the pass PRESERVES (the pass does not invalidate the
 // results of these analyses).  This information is provided by a pass to the
 // Pass infrastructure through the getAnalysisUsage virtual function.
 //
 class AnalysisUsage {
   // Sets of analyses required and preserved by a pass
-  std::vector<AnalysisID> Required, Preserved;
+  std::vector<AnalysisID> Required, RequiredTransitive, Preserved;
   bool PreservesAll;
 public:
   AnalysisUsage() : PreservesAll(false) {}
@@ -51,6 +52,15 @@
     return *this;
   }
 
+  template<class PassClass>
+  AnalysisUsage &addRequiredTransitive() {
+    AnalysisID ID = Pass::getClassPassInfo<PassClass>();
+    assert(ID && "Pass class not registered!");
+    Required.push_back(ID);
+    RequiredTransitive.push_back(ID);
+    return *this;
+  }
+
   // addPreserved - Add the specified ID to the set of analyses preserved by
   // this pass
   //
@@ -82,6 +92,9 @@
   void setPreservesCFG();
 
   const std::vector<AnalysisID> &getRequiredSet() const { return Required; }
+  const std::vector<AnalysisID> &getRequiredTransitiveSet() const {
+    return RequiredTransitive;
+  }
   const std::vector<AnalysisID> &getPreservedSet() const { return Preserved; }
 };
 
@@ -25,14 +25,15 @@
 //===----------------------------------------------------------------------===//
 // AnalysisUsage - Represent the analysis usage information of a pass.  This
-// tracks analyses that the pass REQUIRES (must available when the pass runs),
-// and analyses that the pass PRESERVES (the pass does not invalidate the
-// results of these analyses).  This information is provided by a pass to the
+// tracks analyses that the pass REQUIRES (must be available when the pass 
+// runs), REQUIRES TRANSITIVE (must be available throughout the lifetime of the
+// pass), and analyses that the pass PRESERVES (the pass does not invalidate the
+// results of these analyses).  This information is provided by a pass to the 
 // Pass infrastructure through the getAnalysisUsage virtual function.
 //





More information about the llvm-commits mailing list